@@ -10,13 +10,12 @@ from typing import cast
 from typing import Generator
 from typing import IO
 from typing import Iterable
-from typing import List
 from typing import Optional
-from typing import Tuple
 from typing import TypeVar
 from typing import Union
 
 import configobj
+from cryptography import x509
 import josepy as jose
 from josepy import b64
 
@@ -86,7 +85,7 @@ def _suggest_donation_if_appropriate(config: configuration.NamespaceConfig) -> N
 
 
 def _get_and_save_cert(le_client: client.Client, config: configuration.NamespaceConfig,
-                       domains: Optional[List[str]] = None, certname: Optional[str] = None,
+                       domains: Optional[list[str]] = None, certname: Optional[str] = None,
                        lineage: Optional[storage.RenewableCert] = None
                        ) -> Optional[storage.RenewableCert]:
     """Authenticate and enroll certificate.
@@ -114,7 +113,7 @@ def _get_and_save_cert(le_client: client.Client, config: configuration.Namespace
 
     """
     hooks.pre_hook(config)
-    renewed_domains: List[str] = []
+    renewed_domains: list[str] = []
 
     try:
         if lineage is not None:
@@ -199,7 +198,7 @@ def _handle_unexpected_key_type_migration(config: configuration.NamespaceConfig,
 def _handle_subset_cert_request(config: configuration.NamespaceConfig,
                                 domains: Iterable[str],
                                 cert: storage.RenewableCert
-                                ) -> Tuple[str, Optional[storage.RenewableCert]]:
+                                ) -> tuple[str, Optional[storage.RenewableCert]]:
     """Figure out what to do if a previous cert had a subset of the names now requested
 
     :param config: Configuration object
@@ -246,7 +245,7 @@ def _handle_subset_cert_request(config: configuration.NamespaceConfig,
 
 def _handle_identical_cert_request(config: configuration.NamespaceConfig,
                                    lineage: storage.RenewableCert,
-                                   ) -> Tuple[str, Optional[storage.RenewableCert]]:
+                                   ) -> tuple[str, Optional[storage.RenewableCert]]:
     """Figure out what to do if a lineage has the same names as a previously obtained one
 
     :param config: Configuration object
@@ -264,8 +263,14 @@ def _handle_identical_cert_request(config: configuration.NamespaceConfig,
 
     if not lineage.ensure_deployed():
         return "reinstall", lineage
-    if is_key_type_changing or renewal.should_renew(config, lineage):
+    if is_key_type_changing:
         return "renew", lineage
+
+    ari_clients = renewal.AriClientPool(config)
+
+    if renewal.should_renew(config, lineage, ari_clients):
+        return "renew", lineage
+
     if config.reinstall:
         # Set with --reinstall, force an identical certificate to be
         # reinstalled without further prompting.
@@ -298,8 +303,8 @@ def _handle_identical_cert_request(config: configuration.NamespaceConfig,
     raise AssertionError('This is impossible')
 
 
-def _find_lineage_for_domains(config: configuration.NamespaceConfig, domains: List[str]
-                              ) -> Tuple[Optional[str], Optional[storage.RenewableCert]]:
+def _find_lineage_for_domains(config: configuration.NamespaceConfig, domains: list[str]
+                              ) -> tuple[Optional[str], Optional[storage.RenewableCert]]:
     """Determine whether there are duplicated names and how to handle
     them (renew, reinstall, newcert, or raising an error to stop
     the client run if the user chooses to cancel the operation when
@@ -339,8 +344,8 @@ def _find_lineage_for_domains(config: configuration.NamespaceConfig, domains: Li
     return None, None
 
 
-def _find_cert(config: configuration.NamespaceConfig, domains: List[str], certname: str
-               ) -> Tuple[bool, Optional[storage.RenewableCert]]:
+def _find_cert(config: configuration.NamespaceConfig, domains: list[str], certname: str
+               ) -> tuple[bool, Optional[storage.RenewableCert]]:
     """Finds an existing certificate object given domains and/or a certificate name.
 
     :param config: Configuration object
@@ -365,8 +370,8 @@ def _find_cert(config: configuration.NamespaceConfig, domains: List[str], certna
 
 
 def _find_lineage_for_domains_and_certname(
-        config: configuration.NamespaceConfig, domains: List[str],
-        certname: str) -> Tuple[Optional[str], Optional[storage.RenewableCert]]:
+        config: configuration.NamespaceConfig, domains: list[str],
+        certname: str) -> tuple[Optional[str], Optional[storage.RenewableCert]]:
     """Find appropriate lineage based on given domains and/or certname.
 
     :param config: Configuration object
@@ -410,7 +415,7 @@ def _find_lineage_for_domains_and_certname(
 T = TypeVar("T")
 
 
-def _get_added_removed(after: Iterable[T], before: Iterable[T]) -> Tuple[List[T], List[T]]:
+def _get_added_removed(after: Iterable[T], before: Iterable[T]) -> tuple[list[T], list[T]]:
     """Get lists of items removed from `before`
     and a lists of items added to `after`
     """
@@ -475,7 +480,7 @@ def _ask_user_to_confirm_new_names(config: configuration.NamespaceConfig,
 
 def _find_domains_or_certname(config: configuration.NamespaceConfig,
                               installer: Optional[interfaces.Installer],
-                              question: Optional[str] = None) -> Tuple[List[str], str]:
+                              question: Optional[str] = None) -> tuple[list[str], str]:
     """Retrieve domains and certname from config or user input.
 
     :param config: Configuration object
@@ -536,7 +541,7 @@ def _report_next_steps(config: configuration.NamespaceConfig, installer_err: Opt
                                      being saved (created or renewed).
 
     """
-    steps: List[str] = []
+    steps: list[str] = []
 
     # If the installation or enhancement raised an error, show advice on trying again
     if installer_err:
@@ -689,7 +694,7 @@ def _csr_report_new_cert(config: configuration.NamespaceConfig, cert_path: Optio
 
 
 def _determine_account(config: configuration.NamespaceConfig
-                       ) -> Tuple[account.Account,
+                       ) -> tuple[account.Account,
                                   Optional[acme_client.ClientV2]]:
     """Determine which account to use.
 
@@ -1030,7 +1035,7 @@ def _cert_name_from_config_or_lineage(config: configuration.NamespaceConfig,
 
 
 def _install_cert(config: configuration.NamespaceConfig, le_client: client.Client,
-                  domains: List[str], lineage: Optional[storage.RenewableCert] = None) -> None:
+                  domains: list[str], lineage: Optional[storage.RenewableCert] = None) -> None:
     """Install a cert
 
     :param config: Configuration object
@@ -1089,7 +1094,7 @@ def install(config: configuration.NamespaceConfig,
             custom_prompt=certname_question)[0]
 
     if not enhancements.are_supported(config, installer):
-        raise errors.NotSupportedError("One ore more of the requested enhancements "
+        raise errors.NotSupportedError("One or more of the requested enhancements "
                                        "are not supported by the selected installer")
     # If cert-path is defined, populate missing (ie. not overridden) values.
     # Unfortunately this can't be done in argument parser, as certificate
@@ -1213,7 +1218,7 @@ def enhance(config: configuration.NamespaceConfig,
         return str(e)
 
     if not enhancements.are_supported(config, installer):
-        raise errors.NotSupportedError("One ore more of the requested enhancements "
+        raise errors.NotSupportedError("One or more of the requested enhancements "
                                        "are not supported by the selected installer")
 
     certname_question = ("Which certificate would you like to use to enhance "
@@ -1264,26 +1269,6 @@ def rollback(config: configuration.NamespaceConfig, plugins: plugins_disco.Plugi
     client.rollback(config.installer, config.checkpoints, config, plugins)
 
 
-def rename(config: configuration.NamespaceConfig,
-           unused_plugins: plugins_disco.PluginsRegistry) -> None:
-    """Rename a certificate
-
-    Use the information in the config file to rename an existing
-    lineage.
-
-    :param config: Configuration object
-    :type config: configuration.NamespaceConfig
-
-    :param unused_plugins: List of plugins (deprecated)
-    :type unused_plugins: plugins_disco.PluginsRegistry
-
-    :returns: `None`
-    :rtype: None
-
-    """
-    cert_manager.rename_lineage(config)
-
-
 def delete(config: configuration.NamespaceConfig,
            unused_plugins: plugins_disco.PluginsRegistry) -> None:
     """Delete a certificate
@@ -1357,17 +1342,17 @@ def revoke(config: configuration.NamespaceConfig,
         crypto_util.verify_cert_matches_priv_key(config.cert_path, config.key_path)
         with open(config.key_path, 'rb') as f:
             key = jose.JWK.load(f.read())
-        acme = client.acme_from_config_key(config, key)
+        acme = client.create_acme_client(config, key)
     else:  # revocation by account key
         logger.debug("Revoking %s using Account Key", config.cert_path)
         acc, _ = _determine_account(config)
-        acme = client.acme_from_config_key(config, acc.key, acc.regr)
+        acme = client.create_acme_client(config, acc.key, acc.regr)
 
     with open(config.cert_path, 'rb') as f:
-        cert = crypto_util.pyopenssl_load_certificate(f.read())[0]
+        cert = x509.load_pem_x509_certificate(f.read())
     logger.debug("Reason code for revocation: %s", config.reason)
     try:
-        acme.revoke(jose.ComparableX509(cert), config.reason)
+        acme.revoke(cert, config.reason)
         _delete_if_appropriate(config)
     except acme_errors.ClientError as e:
         return str(e)
@@ -1413,7 +1398,7 @@ def run(config: configuration.NamespaceConfig,
 
     # Preflight check for enhancement support by the selected installer
     if not enhancements.are_supported(config, installer):
-        raise errors.NotSupportedError("One ore more of the requested enhancements "
+        raise errors.NotSupportedError("One or more of the requested enhancements "
                                        "are not supported by the selected installer")
 
     # TODO: Handle errors from _init_le_client?
@@ -1462,7 +1447,7 @@ def run(config: configuration.NamespaceConfig,
 
 
 def _csr_get_and_save_cert(config: configuration.NamespaceConfig,
-                           le_client: client.Client) -> Tuple[
+                           le_client: client.Client) -> tuple[
                            Optional[str], Optional[str], Optional[str]]:
     """Obtain a cert using a user-supplied CSR
 
@@ -1612,13 +1597,7 @@ def renew(config: configuration.NamespaceConfig,
     :rtype: None
 
     """
-
-    renewed_domains: List[str] = []
-    failed_domains: List[str] = []
-    try:
-        renewed_domains, failed_domains = renewal.handle_renewal_request(config)
-    finally:
-        hooks.run_saved_post_hooks(renewed_domains, failed_domains)
+    renewal.handle_renewal_request(config)
 
 
 def make_or_verify_needed_dirs(config: configuration.NamespaceConfig) -> None:
@@ -1822,7 +1801,7 @@ def make_displayer(config: configuration.NamespaceConfig
             devnull.close()
 
 
-def main(cli_args: Optional[List[str]] = None) -> Optional[Union[str, int]]:
+def main(cli_args: Optional[list[str]] = None) -> Optional[Union[str, int]]:
     """Run Certbot.
 
     :param cli_args: command line to Certbot, defaults to ``sys.argv[1:]``
